==> haskell-hsini-0.5.2.2-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hsini
version:              0.5.2.2
visibility:           public
id:                   hsini-0.5.2.2-9kJfEH6H7tM2g12iCqJO2Y
key:                  hsini-0.5.2.2-9kJfEH6H7tM2g12iCqJO2Y
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
author:               Magnus Therning <magnus@therning.org>
synopsis:             ini configuration files
description:
    Library for reading and writing configuration files in INI format (see <https://en.wikipedia.org/wiki/INI_file>).

category:             Configuration, Data
abi:                  abe521bdb890f08527b167ebac0c5ee6
exposed:              True
exposed-modules:
    Data.Ini Data.Ini.Reader Data.Ini.Reader.Internals Data.Ini.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsini
hs-libraries:         HShsini-0.5.2.2-9kJfEH6H7tM2g12iCqJO2Y
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1

haddock-interfaces:   /usr/share/doc/haskell-hsini/html/hsini.haddock
haddock-html:         /usr/share/doc/haskell-hsini/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsini-0.5.2.2-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hsini
version:              0.5.2.2
visibility:           public
id:                   hsini-0.5.2.2-4QpY0D9gXcgGP2vPbuL8wr
key:                  hsini-0.5.2.2-4QpY0D9gXcgGP2vPbuL8wr
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
author:               Magnus Therning <magnus@therning.org>
synopsis:             ini configuration files
description:
    Library for reading and writing configuration files in INI format (see <https://en.wikipedia.org/wiki/INI_file>).

category:             Configuration, Data
abi:                  5132defcf2d3cdfd003031eccc983edf
exposed:              True
exposed-modules:
    Data.Ini Data.Ini.Reader Data.Ini.Reader.Internals Data.Ini.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hsini-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsini
hs-libraries:         HShsini-0.5.2.2-4QpY0D9gXcgGP2vPbuL8wr
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1

haddock-interfaces:   /usr/share/doc/haskell-hsini/html/hsini.haddock
haddock-html:         /usr/share/doc/haskell-hsini/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
